/*
MIT License

Copyright (c) 2021 Famedly

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
*/

import 'json_rest_api_client.dart';

/// Represents a response from a successful request to a json REST API.
class JsonRestApiResponse {
  /// The http method used in this request like `GET` or `POST`.
  final RequestMethod method;

  /// The endpoint this request was sent to.
  final String endpoint;

  /// The returned status code which should be around 200-205
  final int statusCode;

  /// The response json if there is any
  final Map<String, dynamic>? jsonObject;

  /// Some API endpoints may return an array and not a json object. For this
  /// case, this is used.
  final List<dynamic>? jsonArray;

  /// The raw body response.
  final String raw;

  /// Constructor for a new JsonRestApiResponse.
  JsonRestApiResponse({
    required this.method,
    required this.endpoint,
    required this.statusCode,
    required this.raw,
    this.jsonObject,
    this.jsonArray,
  });
}
