import 'dart:convert';

import 'package:json_rest_api_client/json_rest_api_client.dart';
import 'package:test/test.dart';

import 'package:http/http.dart';
import 'package:http/testing.dart';

void main() {
  group('A group of tests', () {
    late JsonRestApiClient client;

    setUp(() {
      client = JsonRestApiClient(
        Uri.parse('http://localhost'),
        httpClient: FakeApi(),
      );
    });

    test('GET json', () async {
      final response = await client.request(
        RequestMethod.get,
        '/v1/test',
        queryParameters: {'foo': 'bar'},
      );
      expect(response.jsonObject!['message'], 'Hello world');
      expect(
          response.jsonObject!['action'], 'http://localhost/v1/test?foo=bar');
    });

    test('GET array', () async {
      final response = await client.request(
        RequestMethod.get,
        '/v1/test',
        queryParameters: {'foo': 'bar'},
        json: ['foo', 'bar'],
      );
      expect(response.jsonArray, ["foo", "bar"]);
    });

    test('POST json', () async {
      final response = await client.request(
        RequestMethod.post,
        '/v1/test',
        json: {'foo': 'bar'},
      );
      expect(response.jsonObject!['body'], '{"foo":"bar"}');
    });
  });
}

class FakeApi extends MockClient {
  FakeApi()
      : super((request) async {
          if (request.body.startsWith('[')) {
            return Response('["foo","bar"]', 200);
          }
          return Response(
              jsonEncode(<String, dynamic>{
                'action': request.url.toString(),
                'method': request.method,
                'body': request.body,
                'message': 'Hello world',
                'time': DateTime.now().millisecondsSinceEpoch,
              }),
              200);
        });
}
